@@ -4,7 +4,6 @@ Download and build FreeTDS library and build pymssql.
 """
 
 import argparse
-from distutils.util import get_platform
 import multiprocessing
 import os
 from pathlib import Path
@@ -17,6 +16,7 @@ import tarfile
 
 def run(cmd, cwd=None, env=None, shell=True):
 
+    print(f"build.py: {cmd}")
     check_call(str(cmd), cwd=str(cwd) if cwd else cwd, env=env, shell=shell, stderr=STDOUT)
 
 
@@ -85,7 +85,7 @@ def build(args, freetds_archive):
         configure.extend(["--enable-shared", "--disable-static"])
     cmd = ' '.join(configure)
     env = os.environ.copy()
-    env.update(CFLAGS="-fPIC")
+    env.update(CFLAGS="-fPIC -Wno-incompatible-pointer-types")
     run(cmd, cwd=blddir, env=env)
     make = f"make -j {multiprocessing.cpu_count()}"
     run(make, cwd=blddir, env=env)
@@ -96,8 +96,13 @@ def build(args, freetds_archive):
 def find_vcvarsall_env():
 
     from distutils import _msvccompiler as _msvcc
+    from distutils.util import get_platform
 
     plat_name = get_platform()
+    CIBW_ARCHS_WINDOWS = os.environ.get("CIBW_ARCHS_WINDOWS")
+    if CIBW_ARCHS_WINDOWS == 'x86':
+        plat_name = 'win32'
+
     try:
         plat_spec = _msvcc.PLAT_TO_VCVARS[plat_name]
     except AttributeError:
@@ -119,6 +124,7 @@ def find_vcvarsall_env():
 def build_windows(args, freetds_archive, iconv_archive):
 
     from zipfile import ZipFile
+
     wiconv = args.ws_dir / "win-iconv"
     if wiconv.exists():
         shutil.rmtree(wiconv)
@@ -204,7 +210,7 @@ def parse_args(argv):
 
     a('-f', '--force-download', action='store_true',
             help="force archive download")
-    a('-u', '--freetds-url', default="http://ftp.freetds.org/pub/freetds/stable",
+    a('-u', '--freetds-url', default="https://www.freetds.org/files/stable/",
             help="URL to download FreeTDS archive")
     a('-v', '--freetds-version', default='', type=freetds_version,
             help="""Specific FreeTDS version to build or 'latest'.
@@ -224,6 +230,9 @@ def parse_args(argv):
             help="workspace directory for building FreeTDS")
     a('-p', '--prefix', default=None, type=lambda x: Path(x) if x else None,
             help="prefix for installing FreeTDS, default is WS_DIR/prefix")
+
+    a('-W', '--wheel', action='store_true',
+            help="Build wheel.")
     a('-d', '--dist-dir', default=Path('./dist'), type=Path,
             help="where to put pymssql wheel, default is './dist'")
     a('-s', '--sdist', action='store_true',
@@ -258,10 +267,11 @@ def main(argv):
     else:
         build(args, freetds_archive)
 
-    args.dist_dir = args.dist_dir.absolute()
-    env = os.environ.copy()
-    env.update(PYMSSQL_FREETDS=f"{args.prefix}")
-    run(f"{sys.executable} -m pip wheel . -w {args.dist_dir}", shell=True, env=env)
+    if args.wheel:
+        args.dist_dir = args.dist_dir.absolute()
+        env = os.environ.copy()
+        env.update(PYMSSQL_FREETDS=f"{args.prefix}")
+        run(f"{sys.executable} -m pip wheel . -w {args.dist_dir}", shell=True, env=env)
     if args.sdist:
         fmt = 'zip' if platform.system() == 'Windows' else 'gztar'
         run(f"{sys.executable} setup.py sdist --formats={fmt} -d {args.dist_dir}", shell=True, env=env)
